# Avatar Python Client

## Documentation

Documentation is available here: <https://python.docs.octopize.io/>

## Requirements

The `avatars` package requires Python 3.9 or above.

## Installation

See our [documentation](https://python.docs.octopize.io/latest/installation.html) for installation instructions.

## License

This software is made available through the Apache License 2.0.

## Contact

<help@octopize.io>
